@@ -16,7 +16,7 @@ def test_save_table_calls_blob_client(fake_blob, monkeypatch):
     df = pd.DataFrame({"x": [1]})
     cloud.save_table("t1", df, directory="dir")
     assert captured["path"] == "dir/t1.parquet"
-    assert captured["df"].equals(df)
+    assert captured["df"].equals(df.astype(str))
     
 
 def test_incremental_load_merges_correctly(fake_blob, monkeypatch):
